DEF VAR sp-companycode AS CHAR NO-UNDO.
DEF VAR lOk            AS LOG  NO-UNDO INIT TRUE.
DEF VAR iLoop          AS INT  NO-UNDO.
DEF VAR iMoveref       AS INT  NO-UNDO.
DEF VAR lUpdate        AS LOG  NO-UNDO.
DEF VAR cStatus        AS CHAR NO-UNDO.
DEF VAR cSubleaseStart AS CHAR NO-UNDO.
DEF VAR cSubleaseStop  AS CHAR NO-UNDO.
DEF VAR cLeasetypes    AS CHAR NO-UNDO.
DEF VAR cMessage       AS CHAR NO-UNDO.
def var iDateSeq       as int  no-undo.

DEF BUFFER b-ec-container_history       FOR ec-container_history.
DEF BUFFER b-ec-container_history-START FOR ec-container_history.
DEF BUFFER b-ec-container_history-STOP  FOR ec-container_history.
DEF BUFFER b-ec-container_history-ADD   FOR ec-container_history.
DEF BUFFER b-ec-sequence                FOR ec-sequence.

disable triggers for load of b-ec-container_history-START.
disable triggers for load of b-ec-container_history-STOP.
disable triggers for load of b-ec-container_history-ADD.


DEFINE TEMP-TABLE tt-log NO-UNDO
            FIELD containerprefix AS CHAR
            FIELD containernr     AS CHAR
            FIELD dt_move         AS DATE
            FIELD statuscode      AS CHAR
            FIELD ind_ok          AS LOG
            FIELD messagetext     AS CHAR
            INDEX tt-log AS PRIMARY containerprefix containernr dt_move.

sp-companycode = "VIA".
lUpdate        = false.

MESSAGE "Database triggers are NOT disabled in this conversion program, so please make sure you loged on for companycode" sp-companycode "!" SKIP(1)
        (IF lUpdate THEN "** UPDATE IS TURNED ON - MOVES WILL BE UPDATED/CREATED ** " ELSE "Update is turned off - Test only") SKIP(1)
        "Continue?" VIEW-AS ALERT-BOX WARNING BUTTONS YES-NO UPDATE lOk.
IF lOk = FALSE THEN RETURN.

FIND b-ec-sequence WHERE
     b-ec-sequence.sequencecode = "ec-move-reference" + sp-companycode
     NO-LOCK NO-ERROR.
IF NOT AVAIL b-ec-sequence
THEN DO:
  MESSAGE "Move sequence code (ec-sequence) not found." SKIP
          "Please check if the companycode is correct."
          VIEW-AS ALERT-BOX.
  lOk = FALSE.
END.

FOR EACH ec-status WHERE
         ec-status.companycode = sp-companycode:
  IF ec-status.actioncontract = "SL"
  THEN cSubleaseStart = cSubleaseStart + (IF cSubleaseStart = "" THEN "" ELSE ",")
                      + ec-status.statuscode.
  IF ec-status.actioncontract = "SO"
  THEN cSubleaseStop = cSubleaseStop + (IF cSubleaseStop = "" THEN "" ELSE ",")
                     + ec-status.statuscode.
END.

FOR EACH aa-lease WHERE
         aa-lease.companycode        = sp-companycode
     AND aa-lease.ind_allow_sublease = TRUE:
  cLeasetypes = cLeasetypes + (IF cLeasetypes = "" THEN "" ELSE ",")
                      + aa-lease.leasecode.
END.

IF cSubLeaseStart = ""
THEN DO:
  MESSAGE "No sublease status START codes found." SKIP
          "Conversion not needed."
          VIEW-AS ALERT-BOX.
  lOk = FALSE.
END.

IF cSubLeaseStop = "" AND lOk
THEN DO:
  MESSAGE "No sublease status STOP codes found." SKIP
          "Please add a sublease STOP status before running this conversion."
          VIEW-AS ALERT-BOX.
  lOk = FALSE.
END.

IF NUM-ENTRIES(cSubLeaseStop) > 1 AND lOk
THEN DO:
  MESSAGE "Please supply ONE sublease STOP status code." SKIP
          "Multiple found:" cSubleaseStop
          VIEW-AS ALERT-BOX.
  lOk = FALSE.
END.

IF cLeasetypes = ""  AND lOk
THEN DO:
  MESSAGE "No lease type codes found that allow sublease." SKIP
          "Please update current lease type codes."
          VIEW-AS ALERT-BOX.
  lOk = FALSE.
END.

IF lOk
THEN DO:
  DO iLoop = 1 TO NUM-ENTRIES(cSubleaseStop):

    cStatus = ENTRY(iLoop,cSubleaseStop).
    container:
    FOR EACH b-ec-container_history NO-LOCK WHERE
             b-ec-container_history.companycode  = sp-companycode
         AND b-ec-container_history.statuscode   = cStatus
         AND b-ec-container_history.ind_sublease = FALSE
             USE-INDEX statuscode:

    /* if b-ec-container_history.containernr <> '9718109' then next container. */

      lOk      = TRUE.
      cMessage = "".


      IF lOk
      THEN DO:
        FIND ec-container WHERE
             ec-container.companycode     = b-ec-container_history.companycode
         AND ec-container.containerprefix = b-ec-container_history.containerprefix
         AND ec-container.containernr     = b-ec-container_history.containernr
             NO-LOCK NO-ERROR.
        IF NOT AVAIL ec-container
        THEN DO:
          lOk      = FALSE.
          cMessage = "Container not found.".
        END.
        ELSE DO:
          IF ec-container.ind_soc = TRUE
          THEN DO:
            /*lOk      = FALSE.*/
            cMessage = "Container is a shippers owned container.".
          END.
        END.
      END.

      IF lOk
      THEN DO:

        IF TRUE
        THEN DO:

          blok:
          DO TRANSACTION ON ERROR UNDO blok, LEAVE blok:

            FIND b-ec-container_history-STOP WHERE ROWID(b-ec-container_history-STOP) = ROWID(b-ec-container_history) EXCLUSIVE.

            /* eerst (eventueel) sublease STOP wegschrijven */
            FIND b-ec-container_history-START WHERE ROWID(b-ec-container_history-START) = ROWID(b-ec-container_history) NO-LOCK.
            FIND PREV b-ec-container_history-START WHERE
                      b-ec-container_history-START.companycode     = b-ec-container_history.companycode
                  AND b-ec-container_history-START.containerprefix = b-ec-container_history.containerprefix
                  AND b-ec-container_history-START.containernr     = b-ec-container_history.containernr
                      USE-INDEX dt_move NO-LOCK NO-ERROR.
            IF AVAIL b-ec-container_history-START and lookup(b-ec-container_history-START.statuscode,cSubleaseStart) = 0
            THEN DO:
              cMessage = "Previous move is not SUBL but " + b-ec-container_history-START.statuscode.
            END.
          END.
        END.
      END.

      CREATE tt-log.
      ASSIGN tt-log.containerprefix = b-ec-container_history.containerprefix
             tt-log.containernr     = b-ec-container_history.containernr
             tt-log.dt_move         = b-ec-container_history.dt_move
             tt-log.statuscode      = b-ec-container_history.statuscode
             tt-log.ind_ok          = lOk
             tt-log.messagetext     = cMessage.

    END.

  END.

END.


OUTPUT TO VALUE(SESSION:TEMP-DIR + "ec-sublease-conversion.txt").
PUT UNFORMATTED "Container" AT 1
                "Move date" AT 15
                "Status"    AT 26
                "Ok"        AT 37
                "Error"     AT 45 SKIP FILL("-",80) SKIP.
FOR EACH tt-log NO-LOCK :
  PUT UNFORMATTED tt-log.containerprefix AT 1
                  tt-log.containernr     AT 6
                  string(tt-log.dt_move,"99/99/9999") AT 15
                  tt-log.statuscode                   AT 26
                  tt-log.ind_ok                       AT 37
                  tt-log.messagetext                  AT 45 SKIP.
END.
OUTPUT CLOSE.


MESSAGE "Finished." SKIP(1)
        "Please check" SESSION:TEMP-DIR + "ec-sublease-conversion.txt"
        VIEW-AS ALERT-BOX.
